/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_LAUNCHER_H
#define __KIBA_LAUNCHER_H

#include <glib.h>
#include <kiba-window.h>
#include <kiba-icon-view-win.h>
#include <kiba-desktop-icon.h>

G_BEGIN_DECLS

typedef struct _KibaLauncher         KibaLauncher;
typedef struct _KibaLauncherClass    KibaLauncherClass;

#define KIBA_TYPE_LAUNCHER           (kiba_launcher_get_type ())
#define KIBA_LAUNCHER(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_LAUNCHER, KibaLauncher))
#define KIBA_LAUNCHER_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TYPE_LAUNCHER,  KibaLauncherClass))
#define KIBA_IS_LAUNCHER(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_LAUNCHER))
#define KIBA_IS_LAUNCHER_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_LAUNCHER))
#define KIBA_LAUNCHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_LAUNCHER, KibaLauncherClass))

#define LAUNCHER_PLUGIN_NAME  "launcher"
#define LAUNCHER_DIR          "/.kiba-dock/" LAUNCHER_PLUGIN_NAME

typedef enum {
	KIBA_LAUNCHER_GROUPING = 0,
	KIBA_LAUNCHER_CONTROL_CLASS,
	KIBA_LAUNCHER_FLAG_NONE
}KibaLauncherFlags;

typedef struct {
	KibaLauncher     *launcher;
	KibaIconViewWin  *view_win;
	char             *id;         /* the group id (a Categorie or so) */
	GtkWidget        *widget;     /* the KibaIcon Instance, representing the group */
	GList            *icons;      /* list with KibaDesktopIcon's from group,
				     the first one is the current active one */
	gint              count;      /* num of icons added to the group */
}KibaLauncherIconGroup;

struct _KibaLauncher {
	GObject           parent;
	
	KibaPlugin       *plugin;
	
	KibaLauncherFlags flags;
	float            alpha;
	float            size_scale;
	
	GList            *icons;   /* list with all KibaLauncherIcon's */
	GList            *groups;  /* list with all KibaLauncherIconGroup's */
	
	/* FIXME: the static signal_id may is { 0, 0... } from other modules */
	guint *launcher_signals;
};

struct _KibaLauncherClass {
	GObjectClass parent_class;
	
	void (* icon_added) (KibaLauncher    *launcher,
			     KibaDesktopIcon *icon);
	void (* icon_removed) (KibaLauncher    *laucher,
			       KibaDesktopIcon *icon);
};

KibaLauncher* kiba_launcher_new (GTypeModule *type_module);

KibaLauncher* kiba_launcher_get (void);

void kiba_launcher_add (KibaLauncher    *launcher,
			KibaDesktopIcon *icon);

void kiba_launcher_remove (KibaLauncher    *launcher,
			   KibaDesktopIcon *icon);

void kiba_launcher_set_flag (KibaLauncher *launcher,
			     gint          flag);

void kiba_launcher_unset_flag (KibaLauncher *launcher,
			       gint          flag);

KibaDesktopIcon* kiba_launcher_get_icon_for_widget (KibaLauncher *launcher,
						    GtkWidget    *widget);

KibaDesktopIcon* kiba_launcher_get_icon_for_window (KibaLauncher *launcher,
						    KibaWindow   *window);

KibaDesktopIcon* kiba_launcher_get_icon_for_class (KibaLauncher *launcher,
						   const char   *wmclass);

void kiba_launcher_destroy (KibaLauncher *launcher);

#endif
